@@ -98,9 +98,8 @@ class MuminDataset:
               Multimodal Fact-Checked Misinformation Dataset with Linked Social
               Network Posts_ (2021)
     '''
-    download_url: str = ('https://github.com/CLARITI-REPHRAIN/mumin-build/raw/'
-                         '22cbc45ad014464a0ee37338a61de1e5e64e756a'
-                         '/data/mumin.zip')
+    download_url: str = ('https://data.bris.ac.uk/datasets/23yv276we2mll25f'
+                         'jakkfim2ml/23yv276we2mll25fjakkfim2ml.zip')
     _node_dump: List[str] = ['claim', 'tweet', 'user', 'image', 'article',
                              'hashtag', 'reply']
     _rel_dump: List[Tuple[str, str, str]] = [
@@ -273,6 +272,16 @@ class MuminDataset:
                             pbar.update(len(data))
                             f.write(data)
 
+                # The data.bris zip file contains two files: `mumin.zip` and
+                # `readme.txt`. We only want the first one, so we extract that
+                # and replace the original file with it.
+                with zipfile.ZipFile(self.dataset_path,
+                                     mode='r',
+                                     compression=zipfile.ZIP_DEFLATED) as zipf:
+                    zipdata = zipf.read('23yv276we2mll25fjakkfim2ml/mumin.zip')
+                with Path(self.dataset_path).open('wb') as f:
+                    f.write(zipdata)
+
             logger.info('Converting dataset to less compressed format')
 
             # Open the zip file containing the dataset
