@@ -2,15 +2,12 @@
 
 from typing import Union
 import requests
-from requests.exceptions import (ConnectionError, InvalidSchema, InvalidURL,
-                                 TooManyRedirects, SSLError)
-from urllib3.exceptions import LocationParseError
-from timeout_decorator import timeout, TimeoutError
+from timeout_decorator import timeout
 import numpy as np
 import warnings
 import time
 import io
-from PIL import Image, UnidentifiedImageError
+from PIL import Image
 
 
 @timeout(10)
@@ -44,9 +41,7 @@ def process_image_url(url: str) -> Union[None, dict]:
 
         try:
             image = download_image_with_timeout(url)
-        except (TimeoutError, UnidentifiedImageError, ConnectionError,
-                InvalidSchema, InvalidURL, TooManyRedirects, SSLError,
-                OSError, LocationParseError):
+        except:  # noqa
             return None
 
         if image is None:
